..
    Copyright (C) 2019 Esteban J. G. Gabancho.

    Flask-SSO-SAML is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.


Configuration
=============

.. automodule:: flask_sso_saml.config
   :members:
